From: Chris Gianelloni <wolf31o2@gentoo.org>
Date: Mon, 17 Sep 2007 19:40:52 +0000 (+0000)
Subject: Changed all instances of EVMS2/LVM2 to EVMS/LVM, respectively.  This will keep everyt... 
X-Git-Tag: v3.4.10.902~217
X-Git-Url: http://git.tremily.us/?a=commitdiff_plain;h=10990c221039a17c078ee57bc0b81d86c10c62e3;p=genkernel.git

Changed all instances of EVMS2/LVM2 to EVMS/LVM, respectively.  This will keep everything simplified if a newer EVMS/LVM version set appears.

git-svn-id: svn+ssh://svn.gentoo.org/var/svnroot/genkernel/trunk@535 67a159dc-881f-0410-a524-ba9dfbe2cb84
---

diff --git a/ChangeLog b/ChangeLog
index 6d96ce3..506d888 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -2,6 +2,16 @@
 # Copyright 2006-2007 Gentoo Foundation; Distributed under the GPL v2
 # $Header: $
 
+  17 Sep 2007; Chris Gianelloni <wolf31o2@gentoo.org> TODO,
+  alpha/modules_load, gen_cmdline.sh, gen_compile.sh, gen_configkernel.sh,
+  gen_determineargs.sh, gen_initramfs.sh, gen_initrd.sh,
+  generic/initrd.defaults, generic/initrd.scripts, generic/linuxrc,
+  genkernel, genkernel.8, genkernel.conf, ia64/modules_load, mips/config.sh,
+  ppc/modules_load, ppc64/modules_load, um/modules_load, x86/modules_load,
+  x86_64/modules_load, xen0/modules_load, xenU/modules_load:
+  Changed all instances of EVMS2/LVM2 to EVMS/LVM, respectively. This will
+  keep everything simplified if a newer EVMS/LVM version set appears.
+
   17 Sep 2007; Chris Gianelloni <wolf31o2@gentoo.org> README,
   alpha/config.sh, gen_bootloader.sh, gen_cmdline.sh, gen_configkernel.sh,
   gen_determineargs.sh, gen_initrd.sh, gen_package.sh, genkernel,
diff --git a/TODO b/TODO
index 72291a6..8a3101a 100644
--- a/TODO
+++ b/TODO
@@ -1,4 +1,4 @@
-- Add LVM2 support, so people that have their root partitions
-  LVM2-ized can boot.
 - Need configs for other currently-unsupported arches.
-
+- Make configs stackable
+- Remove 2.4 kernel support
+- Refactor code to be more simple and extendable
diff --git a/alpha/modules_load b/alpha/modules_load
index 85dfa5f..8b7f360 100644
--- a/alpha/modules_load
+++ b/alpha/modules_load
@@ -3,9 +3,9 @@
 # RAID
 MODULES_ATARAID="ataraid pdcraid hptraid"
 MODULES_DMRAID="dm-mod dm-mirror"
-MODULES_EVMS2="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
+MODULES_EVMS="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
-MODULES_LVM2="dm-mod dm-snapshot dm-mirror dm-bbr"
+MODULES_LVM="dm-mod dm-snapshot dm-mirror dm-bbr"
 MODULES_MDRAID="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
 
diff --git a/gen_cmdline.sh b/gen_cmdline.sh
index a5d9742..44415ca 100755
--- a/gen_cmdline.sh
+++ b/gen_cmdline.sh
@@ -68,14 +68,14 @@ longusage() {
   echo "	--gensplash=<theme>	Force gensplash using <theme>"
   echo "	--gensplash-res=<res>	Select gensplash resolutions"
   echo "	--do-keymap-auto	Forces keymap selection at boot"
-  echo "	--evms			Include EVMS2 support"
+  echo "	--evms			Include EVMS support"
   echo "				--> 'emerge evms' in the host operating system"
   echo "				first"
-  echo "	--evms2			Include EVMS2 support"
+  echo "	--evms2			Include EVMS support"
   echo "				--> 'emerge evms' in the host operating system"
   echo "				first"
-  echo "	--lvm			Include LVM2 support"
-  echo "	--lvm2			Include LVM2 support"
+  echo "	--lvm			Include LVM support"
+  echo "	--lvm2			Include LVM support"
   echo "	--dmraid		Include DMRAID support"
   echo "	--slowusb		Enables extra pauses for slow USB CD boots"
   echo "	--bootloader=grub	Add new kernel to GRUB configuration"
@@ -208,6 +208,8 @@ parse_cmdline() {
 	      --evms2)
 		      CMD_EVMS=1
 		      print_info 2 "CMD_EVMS: ${CMD_EVMS}"
+			  echo
+			  print_warning 1 "Please use --evms, as --evms2 is deprecated."
 	      ;;
 	      --unionfs)
 		      CMD_UNIONFS=1
@@ -220,9 +222,15 @@ parse_cmdline() {
 		      print_warning 1 "This code is subject to change at any time."
 		      echo
 	      ;;
+	      --lvm)
+		      CMD_LVM=1
+		      print_info 2 "CMD_LVM: ${CMD_LVM}"
+	      ;;
 	      --lvm2)
-		      CMD_LVM2=1
-		      print_info 2 "CMD_LVM2: ${CMD_LVM2}"
+		      CMD_LVM=1
+		      print_info 2 "CMD_LVM: ${CMD_LVM}"
+			  echo
+			  print_warning 1 "Please use --lvm, as --lvm2 is deprecated."
 	      ;;
 	      --no-busybox)
 		      CMD_NO_BUSYBOX=1
diff --git a/gen_compile.sh b/gen_compile.sh
index bb9187f..a123ea9 100644
--- a/gen_compile.sh
+++ b/gen_compile.sh
@@ -474,43 +474,43 @@ compile_busybox() {
 	rm -rf "${BUSYBOX_DIR}" > /dev/null
 }
 
-compile_lvm2() {
+compile_lvm() {
 	compile_device_mapper
-	if [ ! -f "${LVM2_BINCACHE}" ]
+	if [ ! -f "${LVM_BINCACHE}" ]
 	then
-		[ -f "${LVM2_SRCTAR}" ] ||
-			gen_die "Could not find LVM2 source tarball: ${LVM2_SRCTAR}! Please place it there, or place another version, changing /etc/genkernel.conf as necessary!"
+		[ -f "${LVM_SRCTAR}" ] ||
+			gen_die "Could not find LVM source tarball: ${LVM_SRCTAR}! Please place it there, or place another version, changing /etc/genkernel.conf as necessary!"
 		cd "${TEMP}"
-		rm -rf ${LVM2_DIR} > /dev/null
-		/bin/tar -zxpf ${LVM2_SRCTAR} ||
-			gen_die 'Could not extract LVM2 source tarball!'
-		[ -d "${LVM2_DIR}" ] ||
-			gen_die 'LVM2 directory ${LVM2_DIR} is invalid!'
+		rm -rf ${LVM_DIR} > /dev/null
+		/bin/tar -zxpf ${LVM_SRCTAR} ||
+			gen_die 'Could not extract LVM source tarball!'
+		[ -d "${LVM_DIR}" ] ||
+			gen_die 'LVM directory ${LVM_DIR} is invalid!'
 		rm -rf "${TEMP}/device-mapper" > /dev/null
 		/bin/tar -jxpf "${DEVICE_MAPPER_BINCACHE}" -C "${TEMP}" ||
 			gen_die "Could not extract device-mapper binary cache!";
 		
-		cd "${LVM2_DIR}"
-		print_info 1 'lvm2: >> Configuring...'
+		cd "${LVM_DIR}"
+		print_info 1 'lvm: >> Configuring...'
 			LDFLAGS="-L${TEMP}/device-mapper/lib" \
 			CFLAGS="-I${TEMP}/device-mapper/include" \
 			CPPFLAGS="-I${TEMP}/device-mapper/include" \
-			./configure --enable-static_link --prefix=${TEMP}/lvm2 >> ${DEBUGFILE} 2>&1 ||
-				gen_die 'Configure of lvm2 failed!'
-		print_info 1 'lvm2: >> Compiling...'
+			./configure --enable-static_link --prefix=${TEMP}/lvm >> ${DEBUGFILE} 2>&1 ||
+				gen_die 'Configure of lvm failed!'
+		print_info 1 'lvm: >> Compiling...'
 			compile_generic '' utils
 			compile_generic 'install' utils
 
-		cd "${TEMP}/lvm2"
+		cd "${TEMP}/lvm"
 		print_info 1 '      >> Copying to bincache...'
 		strip "sbin/lvm.static" ||
 			gen_die 'Could not strip lvm.static!'
-		/bin/tar -cjf "${LVM2_BINCACHE}" sbin/lvm.static ||
+		/bin/tar -cjf "${LVM_BINCACHE}" sbin/lvm.static ||
 			gen_die 'Could not create binary cache'
 
 		cd "${TEMP}"
 		rm -rf "${TEMP}/device-mapper" > /dev/null
-		rm -rf "${LVM2_DIR}" lvm2
+		rm -rf "${LVM_DIR}" lvm
 	fi
 }
 
diff --git a/gen_determineargs.sh b/gen_determineargs.sh
index b9b3c91..a1a3f7b 100644
--- a/gen_determineargs.sh
+++ b/gen_determineargs.sh
@@ -200,7 +200,7 @@ determine_real_args() {
 	DEVFSD_BINCACHE=`cache_replace "${DEVFSD_BINCACHE}"`
 	DEVFSD_CONF_BINCACHE=`cache_replace "${DEVFSD_CONF_BINCACHE}"`
 	DEVICE_MAPPER_BINCACHE=`cache_replace "${DEVICE_MAPPER_BINCACHE}"`
-	LVM2_BINCACHE=`cache_replace "${LVM2_BINCACHE}"`
+	LVM_BINCACHE=`cache_replace "${LVM_BINCACHE}"`
 	DMRAID_BINCACHE=`cache_replace "${DMRAID_BINCACHE}"`
 	UNIONFS_BINCACHE=`cache_replace "${UNIONFS_BINCACHE}"`
 	UNIONFS_MODULES_BINCACHE=`cache_replace "${UNIONFS_MODULES_BINCACHE}"`
@@ -210,7 +210,7 @@ determine_real_args() {
 	BUSYBOX_CONFIG=`arch_replace "${BUSYBOX_CONFIG}"`
 	BUSYBOX_BINCACHE=`arch_replace "${BUSYBOX_BINCACHE}"`
 	DEVICE_MAPPER_BINCACHE=`arch_replace "${DEVICE_MAPPER_BINCACHE}"`
-	LVM2_BINCACHE=`arch_replace "${LVM2_BINCACHE}"`
+	LVM_BINCACHE=`arch_replace "${LVM_BINCACHE}"`
 	DMRAID_BINCACHE=`arch_replace "${DMRAID_BINCACHE}"`
 	UNIONFS_BINCACHE=`arch_replace "${UNIONFS_BINCACHE}"`
 	UNIONFS_MODULES_BINCACHE=`arch_replace "${UNIONFS_MODULES_BINCACHE}"`
@@ -377,18 +377,18 @@ determine_real_args() {
 		OLDCONFIG=0
 	fi
 
-	if isTrue "${CMD_LVM2}"
+	if isTrue "${CMD_LVM}"
 	then
-		LVM2=1
+		LVM=1
 	else
-		LVM2=0
+		LVM=0
 	fi
 
 	if isTrue "${CMD_EVMS}"
 	then
-		EVMS2=1
+		EVMS=1
 	else
-		EVMS2=0
+		EVMS=0
 	fi
 	
 	if isTrue "${CMD_UNIONFS}"
diff --git a/gen_initramfs.sh b/gen_initramfs.sh
index 0342374..b8594d4 100644
--- a/gen_initramfs.sh
+++ b/gen_initramfs.sh
@@ -137,26 +137,26 @@ append_dmraid(){
 	rm -r "${TEMP}/initramfs-dmraid-temp/"
 }
 
-append_lvm2(){
-	if [ -d "${TEMP}/initramfs-lvm2-temp" ]
+append_lvm(){
+	if [ -d "${TEMP}/initramfs-lvm-temp" ]
 	then
-		rm -r "${TEMP}/initramfs-lvm2-temp/"
+		rm -r "${TEMP}/initramfs-lvm-temp/"
 	fi
 	cd ${TEMP}
-	mkdir -p "${TEMP}/initramfs-lvm2-temp/bin/"
-	mkdir -p "${TEMP}/initramfs-lvm2-temp/etc/lvm/"
+	mkdir -p "${TEMP}/initramfs-lvm-temp/bin/"
+	mkdir -p "${TEMP}/initramfs-lvm-temp/etc/lvm/"
 	if [ -e '/sbin/lvm' ] && LC_ALL="C" ldd /sbin/lvm|grep -q 'not a dynamic executable'
 	then
-		print_info 1 '		LVM2: Adding support (using local static binaries)...'
-		cp /sbin/lvm "${TEMP}/initramfs-lvm2-temp/bin/lvm" ||
+		print_info 1 '		LVM: Adding support (using local static binaries)...'
+		cp /sbin/lvm "${TEMP}/initramfs-lvm-temp/bin/lvm" ||
 			gen_die 'Could not copy over lvm!'
 	else
-		print_info 1 '		LVM2: Adding support (compiling binaries)...'
-		compile_lvm2
-		/bin/tar -jxpf "${LVM2_BINCACHE}" -C "${TEMP}/initramfs-lvm2-temp" ||
-			gen_die "Could not extract lvm2 binary cache!";
-		mv ${TEMP}/initramfs-lvm2-temp/sbin/lvm.static ${TEMP}/initramfs-lvm2-temp/bin/lvm ||
-			gen_die 'LVM2 error: Could not move lvm.static to lvm!'
+		print_info 1 '		LVM: Adding support (compiling binaries)...'
+		compile_lvm
+		/bin/tar -jxpf "${LVM_BINCACHE}" -C "${TEMP}/initramfs-lvm-temp" ||
+			gen_die "Could not extract lvm binary cache!";
+		mv ${TEMP}/initramfs-lvm-temp/sbin/lvm.static ${TEMP}/initramfs-lvm-temp/bin/lvm ||
+			gen_die 'LVM error: Could not move lvm.static to lvm!'
 	fi
 	if [ -x /sbin/lvm ]
 	then
@@ -164,66 +164,66 @@ append_lvm2(){
 #		ret=$?
 #		if [ ${ret} != 0 ]
 #		then
-			cp /etc/lvm/lvm.conf "${TEMP}/initramfs-lvm2-temp/etc/lvm/" ||
+			cp /etc/lvm/lvm.conf "${TEMP}/initramfs-lvm-temp/etc/lvm/" ||
 				gen_die 'Could not copy over lvm.conf!'
 #		else
 #			gen_die 'Could not copy over lvm.conf!'
 #		fi
 	fi
-	cd "${TEMP}/initramfs-lvm2-temp/"
+	cd "${TEMP}/initramfs-lvm-temp/"
 	find . -print | cpio ${CPIO_ARGS} --append -F "${CPIO}"
-	rm -r "${TEMP}/initramfs-lvm2-temp/"
+	rm -r "${TEMP}/initramfs-lvm-temp/"
 }
 
-append_evms2(){
-	if [ -d "${TEMP}/initramfs-evms2-temp" ]
+append_evms(){
+	if [ -d "${TEMP}/initramfs-evms-temp" ]
 	then
-		rm -r "${TEMP}/initramfs-evms2-temp/"
+		rm -r "${TEMP}/initramfs-evms-temp/"
 	fi
-	mkdir -p "${TEMP}/initramfs-evms2-temp/lib/evms"
-	mkdir -p "${TEMP}/initramfs-evms2-temp/etc/"
-	mkdir -p "${TEMP}/initramfs-evms2-temp/bin/"
-	mkdir -p "${TEMP}/initramfs-evms2-temp/sbin/"
-	if [ "${EVMS2}" -eq '1' ]
+	mkdir -p "${TEMP}/initramfs-evms-temp/lib/evms"
+	mkdir -p "${TEMP}/initramfs-evms-temp/etc/"
+	mkdir -p "${TEMP}/initramfs-evms-temp/bin/"
+	mkdir -p "${TEMP}/initramfs-evms-temp/sbin/"
+	if [ "${EVMS}" -eq '1' ]
 	then
-		print_info 1 '		EVMS2: Adding support...'
-		mkdir -p ${TEMP}/initramfs-evms2-temp/lib
-		cp -a /lib/ld-* "${TEMP}/initramfs-evms2-temp/lib" \
-			|| gen_die 'Could not copy files for EVMS2!'
+		print_info 1 '		EVMS: Adding support...'
+		mkdir -p ${TEMP}/initramfs-evms-temp/lib
+		cp -a /lib/ld-* "${TEMP}/initramfs-evms-temp/lib" \
+			|| gen_die 'Could not copy files for EVMS!'
 		if [ -n "`ls /lib/libgcc_s*`" ]
 		then
-			cp -a /lib/libgcc_s* "${TEMP}/initramfs-evms2-temp/lib" \
-				|| gen_die 'Could not copy files for EVMS2!'
+			cp -a /lib/libgcc_s* "${TEMP}/initramfs-evms-temp/lib" \
+				|| gen_die 'Could not copy files for EVMS!'
 		fi
-		cp -a /lib/libc-* /lib/libc.* "${TEMP}/initramfs-evms2-temp/lib" \
-			|| gen_die 'Could not copy files for EVMS2!'
-		cp -a /lib/libdl-* /lib/libdl.* "${TEMP}/initramfs-evms2-temp/lib" \
-			|| gen_die 'Could not copy files for EVMS2!'
-		cp -a /lib/libpthread* "${TEMP}/initramfs-evms2-temp/lib" \
-			|| gen_die 'Could not copy files for EVMS2!'
-		cp -a /lib/libuuid*so* "${TEMP}/initramfs-evms2-temp/lib" \
-			|| gen_die 'Could not copy files for EVMS2!'
-		cp -a /lib/libevms*so* "${TEMP}/initramfs-evms2-temp/lib" \
-			|| gen_die 'Could not copy files for EVMS2!'
-		cp -a /lib/evms "${TEMP}/initramfs-evms2-temp/lib" \
-			|| gen_die 'Could not copy files for EVMS2!'
-		cp -a /lib/evms/* "${TEMP}/initramfs-evms2-temp/lib/evms" \
-			|| gen_die 'Could not copy files for EVMS2!'
-		cp -a /etc/evms.conf "${TEMP}/initramfs-evms2-temp/etc" \
-			|| gen_die 'Could not copy files for EVMS2!'
-		cp /sbin/evms_activate "${TEMP}/initramfs-evms2-temp/sbin" \
+		cp -a /lib/libc-* /lib/libc.* "${TEMP}/initramfs-evms-temp/lib" \
+			|| gen_die 'Could not copy files for EVMS!'
+		cp -a /lib/libdl-* /lib/libdl.* "${TEMP}/initramfs-evms-temp/lib" \
+			|| gen_die 'Could not copy files for EVMS!'
+		cp -a /lib/libpthread* "${TEMP}/initramfs-evms-temp/lib" \
+			|| gen_die 'Could not copy files for EVMS!'
+		cp -a /lib/libuuid*so* "${TEMP}/initramfs-evms-temp/lib" \
+			|| gen_die 'Could not copy files for EVMS!'
+		cp -a /lib/libevms*so* "${TEMP}/initramfs-evms-temp/lib" \
+			|| gen_die 'Could not copy files for EVMS!'
+		cp -a /lib/evms "${TEMP}/initramfs-evms-temp/lib" \
+			|| gen_die 'Could not copy files for EVMS!'
+		cp -a /lib/evms/* "${TEMP}/initramfs-evms-temp/lib/evms" \
+			|| gen_die 'Could not copy files for EVMS!'
+		cp -a /etc/evms.conf "${TEMP}/initramfs-evms-temp/etc" \
+			|| gen_die 'Could not copy files for EVMS!'
+		cp /sbin/evms_activate "${TEMP}/initramfs-evms-temp/sbin" \
 			|| gen_die 'Could not copy over evms_activate!'
 
-		# Fix EVMS2 complaining that it can't find the swap utilities.
+		# Fix EVMS complaining that it can't find the swap utilities.
 		# These are not required in the initramfs
-		for swap_libs in "${TEMP}/initramfs-evms2-temp/lib/evms/*/swap*.so"
+		for swap_libs in "${TEMP}/initramfs-evms-temp/lib/evms/*/swap*.so"
 		do
 			rm ${swap_libs}
 		done
 	fi
-	cd "${TEMP}/initramfs-evms2-temp/"
+	cd "${TEMP}/initramfs-evms-temp/"
 	find . -print | cpio ${CPIO_ARGS} --append -F "${CPIO}"
-	rm -r "${TEMP}/initramfs-evms2-temp/"
+	rm -r "${TEMP}/initramfs-evms-temp/"
 }
 
 append_gensplash(){
@@ -433,9 +433,9 @@ create_initramfs() {
 	append_data 'devfs' "${DEVFS}"
 	append_data 'unionfs_modules' "${UNIONFS}"
 	append_data 'unionfs_tools' "${UNIONFS}"
-	append_data 'lvm2' "${LVM2}"
+	append_data 'lvm' "${LVM}"
 	append_data 'dmraid' "${DMRAID}"
-	append_data 'evms2' "${EVMS2}"
+	append_data 'evms' "${EVMS}"
 	
 	if [ "${NOINITRDMODULES}" = '' ]
 	then
diff --git a/generic/initrd.defaults b/generic/initrd.defaults
index a8746ff..46c1c9a 100644
--- a/generic/initrd.defaults
+++ b/generic/initrd.defaults
@@ -78,5 +78,5 @@ CONSOLE="/dev/console"
 
 # Only sections that are in by default or those that
 # are not module groups need to be defined here...
-HWOPTS='usb firewire keymap cache pata sata evms2 lvm2 dmraid mdraid slowusb fs'
+HWOPTS='usb firewire keymap cache pata sata evms lvm dmraid mdraid slowusb fs'
 MY_HWOPTS='usb firewire pata sata dmraid mdraid fs net'
diff --git a/generic/initrd.scripts b/generic/initrd.scripts
index dda77c8..3b1881e 100644
--- a/generic/initrd.scripts
+++ b/generic/initrd.scripts
@@ -616,7 +616,7 @@ startVolumes() {
 		fi
 	fi
 
-	if [ "${USE_LVM2_NORMAL}" -eq '1' ]
+	if [ "${USE_LVM_NORMAL}" -eq '1' ]
 	then
 		if [ -e '/bin/vgscan' -a -e '/bin/vgchange' ]
 		then
@@ -630,20 +630,20 @@ startVolumes() {
 			good_msg "Activating Volume Groups"
 			/bin/vgchange -ay --ignorelockingfailure 2>/dev/null
 
-			# Disable EVMS since lvm2 is activated and they dont work together.
-			if [ "${USE_EVMS2_NORMAL}" -eq '1' ]
+			# Disable EVMS since lvm is activated and they dont work together.
+			if [ "${USE_EVMS_NORMAL}" -eq '1' ]
 			then
-				bad_msg "Disabling EVMS Support because LVM2 started"
-				bad_msg "Do not add dolvm2 to the cmdline if this is not what you want"
-				bad_msg "LVM2 and EVMS do not work well together"
-				USE_EVMS2_NORMAL=0
+				bad_msg "Disabling EVMS Support because LVM started"
+				bad_msg "Do not add dolvm to the cmdline if this is not what you want"
+				bad_msg "LVM and EVMS do not work well together"
+				USE_EVMS_NORMAL=0
 			fi
 		else
-			bad_msg "vgscan or vgchange not found: skipping LVM2 volume group activation!"
+			bad_msg "vgscan or vgchange not found: skipping LVM volume group activation!"
 		fi
 	fi
 
-	if [ "${USE_EVMS2_NORMAL}" -eq '1' ]
+	if [ "${USE_EVMS_NORMAL}" -eq '1' ]
 	then
 		if [ -e '/sbin/evms_activate' ]
 		then
diff --git a/generic/linuxrc b/generic/linuxrc
index 504d2fe..7f36988 100644
--- a/generic/linuxrc
+++ b/generic/linuxrc
@@ -107,8 +107,8 @@ do
 			fi
 		;;
 		# Start Volume manager options 
-		dolvm2)
-			USE_LVM2_NORMAL=1
+		dolvm)
+			USE_LVM_NORMAL=1
 		;;
 		dodmraid)
 			USE_DMRAID_NORMAL=1
@@ -117,8 +117,8 @@ do
 			DMRAID_OPTS=`parse_opt "${x}"`
 			USE_DMRAID_NORMAL=1
 		;;
-		doevms2)
-			USE_EVMS2_NORMAL=1
+		doevms)
+			USE_EVMS_NORMAL=1
 		;;
 		# Debug Options
 		debug)
diff --git a/genkernel b/genkernel
index 8ed59a1..2feab05 100755
--- a/genkernel
+++ b/genkernel
@@ -376,8 +376,8 @@ then
 	print_info 1 'WARNING... WARNING... WARNING...'
 	print_info 1 'Additional kernel cmdline arguments that *may* be required to boot properly...'
 	[ "${GENSPLASH}" -eq '1' ] && print_info 1 "add \"vga=791 splash=silent,theme:${GENSPLASH_THEME} console=tty1 quiet\" if you use a gensplash framebuffer ]"
-	[ "${LVM2}" -eq '1' ] && print_info 1 'add "dolvm2" for lvm2 support'
-	[ "${EVMS2}" -eq '1' ] && print_info 1 'add "doevms2" for evms support'
+	[ "${LVM}" -eq '1' ] && print_info 1 'add "dolvm" for lvm support'
+	[ "${EVMS}" -eq '1' ] && print_info 1 'add "doevms" for evms support'
 	[ "${DMRAID}" -eq '1' ] && print_info 1 'add "dodmraid" for dmraid support'
 	[ "${DMRAID}" -eq '1' ] && print_info 1 '	or "dodmraid=<additional options>"'
 	[ "${UNIONFS}" -eq '1' ] && print_info 1 'add "unionfs" for unionfs support'
diff --git a/genkernel.8 b/genkernel.8
index adbba9b..badee59 100644
--- a/genkernel.8
+++ b/genkernel.8
@@ -190,14 +190,14 @@ Force keymap selection at boot.
 \fB\-\-dmraid\fR
 Add DMRAID support.
 .TP
-\fB\-\-evms2\fR
-Add in EVMS2 support from static binaries if they exist on the system:
-you should run "emerge evms2" first.
+\fB\-\-evms\fR
+Add in EVMS support from static binaries if they exist on the system:
+you should run "emerge evms" first.
 .TP
-\fB\-\-lvm2\fR
+\fB\-\-lvm\fR
 .RS
-Add in LVM2 support from static binaries if they exist on the system,
-or compile static LVM2 binaries if static ones do not exist.
+Add in LVM support from static binaries if they exist on the system,
+or compile static LVM binaries if static ones do not exist.
 .RE
 .TP
 \fB\-\-luks\fR
@@ -275,11 +275,11 @@ Normally used to tell the kernel that it should start a network interface. If pr
 \fBnfsroot=\fR<...>
 If present, the initrd will try to mount a livecd from that location. Otherwise the location will be deduced from the DCHP request (option root\-path)
 .TP
-\fBdoevms2\fR
-Activate EVMS2 volumes on bootup
+\fBdoevms\fR
+Activate EVMS volumes on bootup
 .TP
-\fBdolvm2\fR
-Activate LVM2 volumes on bootup
+\fBdolvm\fR
+Activate LVM volumes on bootup
 .TP
 \fBdoscsi\fR
 Activate SCSI devices on bootup, necessary when SCSI support is compiled as modules and you're using SCSI or SATA devices.
diff --git a/genkernel.conf b/genkernel.conf
index 3227429..9b872ab 100755
--- a/genkernel.conf
+++ b/genkernel.conf
@@ -106,10 +106,10 @@ DEVICE_MAPPER_DIR="device-mapper.${DEVICE_MAPPER_VER}"
 DEVICE_MAPPER_SRCTAR="${GK_SHARE}/pkg/device-mapper.${DEVICE_MAPPER_VER}.tgz"
 DEVICE_MAPPER_BINCACHE="%%CACHE%%/device-mapper-${DEVICE_MAPPER_VER}-%%ARCH%%.tar.bz2"
 
-LVM2_VER="VERSION_LVM2"
-LVM2_DIR="LVM2.${LVM2_VER}"
-LVM2_SRCTAR="${GK_SHARE}/pkg/LVM2.${LVM2_VER}.tgz"
-LVM2_BINCACHE="%%CACHE%%/LVM2.${LVM2_VER}-%%ARCH%%.tar.bz2"
+LVM_VER="VERSION_LVM"
+LVM_DIR="LVM.${LVM_VER}"
+LVM_SRCTAR="${GK_SHARE}/pkg/LVM.${LVM_VER}.tgz"
+LVM_BINCACHE="%%CACHE%%/LVM.${LVM_VER}-%%ARCH%%.tar.bz2"
 
 DMRAID_VER="VERSION_DMRAID"
 DMRAID_DIR="dmraid/${DMRAID_VER}"
diff --git a/ia64/modules_load b/ia64/modules_load
index 85dfa5f..8b7f360 100644
--- a/ia64/modules_load
+++ b/ia64/modules_load
@@ -3,9 +3,9 @@
 # RAID
 MODULES_ATARAID="ataraid pdcraid hptraid"
 MODULES_DMRAID="dm-mod dm-mirror"
-MODULES_EVMS2="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
+MODULES_EVMS="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
-MODULES_LVM2="dm-mod dm-snapshot dm-mirror dm-bbr"
+MODULES_LVM="dm-mod dm-snapshot dm-mirror dm-bbr"
 MODULES_MDRAID="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
 
diff --git a/mips/config.sh b/mips/config.sh
index 92dde07..57641b4 100644
--- a/mips/config.sh
+++ b/mips/config.sh
@@ -11,7 +11,6 @@ UTILS_MAKE=make
 UTILS_CC=gcc
 UTILS_AS=as
 UTILS_LD=ld
-USE_DIETLIBC=0
 
 # Initrd/Initramfs Options
 COMPRESS_INITRD="yes"
@@ -20,9 +19,7 @@ USECOLOR="yes"
 NOINITRDMODULES="yes"
 BUSYBOX=1
 UNIONFS=0
-LVM2=0
 DMRAID=0
-EVMS2=0
 DISKLABEL=0
 
 # genkernel on mips is only used for LiveCDs && netboots.  Catalyst
diff --git a/ppc/modules_load b/ppc/modules_load
index 85dfa5f..8b7f360 100644
--- a/ppc/modules_load
+++ b/ppc/modules_load
@@ -3,9 +3,9 @@
 # RAID
 MODULES_ATARAID="ataraid pdcraid hptraid"
 MODULES_DMRAID="dm-mod dm-mirror"
-MODULES_EVMS2="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
+MODULES_EVMS="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
-MODULES_LVM2="dm-mod dm-snapshot dm-mirror dm-bbr"
+MODULES_LVM="dm-mod dm-snapshot dm-mirror dm-bbr"
 MODULES_MDRAID="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
 
diff --git a/ppc64/modules_load b/ppc64/modules_load
index 85dfa5f..8b7f360 100644
--- a/ppc64/modules_load
+++ b/ppc64/modules_load
@@ -3,9 +3,9 @@
 # RAID
 MODULES_ATARAID="ataraid pdcraid hptraid"
 MODULES_DMRAID="dm-mod dm-mirror"
-MODULES_EVMS2="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
+MODULES_EVMS="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
-MODULES_LVM2="dm-mod dm-snapshot dm-mirror dm-bbr"
+MODULES_LVM="dm-mod dm-snapshot dm-mirror dm-bbr"
 MODULES_MDRAID="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
 
diff --git a/um/modules_load b/um/modules_load
index 85dfa5f..8b7f360 100644
--- a/um/modules_load
+++ b/um/modules_load
@@ -3,9 +3,9 @@
 # RAID
 MODULES_ATARAID="ataraid pdcraid hptraid"
 MODULES_DMRAID="dm-mod dm-mirror"
-MODULES_EVMS2="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
+MODULES_EVMS="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
-MODULES_LVM2="dm-mod dm-snapshot dm-mirror dm-bbr"
+MODULES_LVM="dm-mod dm-snapshot dm-mirror dm-bbr"
 MODULES_MDRAID="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
 
diff --git a/x86/modules_load b/x86/modules_load
index 85dfa5f..8b7f360 100644
--- a/x86/modules_load
+++ b/x86/modules_load
@@ -3,9 +3,9 @@
 # RAID
 MODULES_ATARAID="ataraid pdcraid hptraid"
 MODULES_DMRAID="dm-mod dm-mirror"
-MODULES_EVMS2="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
+MODULES_EVMS="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
-MODULES_LVM2="dm-mod dm-snapshot dm-mirror dm-bbr"
+MODULES_LVM="dm-mod dm-snapshot dm-mirror dm-bbr"
 MODULES_MDRAID="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
 
diff --git a/x86_64/modules_load b/x86_64/modules_load
index 85dfa5f..8b7f360 100644
--- a/x86_64/modules_load
+++ b/x86_64/modules_load
@@ -3,9 +3,9 @@
 # RAID
 MODULES_ATARAID="ataraid pdcraid hptraid"
 MODULES_DMRAID="dm-mod dm-mirror"
-MODULES_EVMS2="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
+MODULES_EVMS="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
-MODULES_LVM2="dm-mod dm-snapshot dm-mirror dm-bbr"
+MODULES_LVM="dm-mod dm-snapshot dm-mirror dm-bbr"
 MODULES_MDRAID="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
 
diff --git a/xen0/modules_load b/xen0/modules_load
index 85dfa5f..8b7f360 100644
--- a/xen0/modules_load
+++ b/xen0/modules_load
@@ -3,9 +3,9 @@
 # RAID
 MODULES_ATARAID="ataraid pdcraid hptraid"
 MODULES_DMRAID="dm-mod dm-mirror"
-MODULES_EVMS2="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
+MODULES_EVMS="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
-MODULES_LVM2="dm-mod dm-snapshot dm-mirror dm-bbr"
+MODULES_LVM="dm-mod dm-snapshot dm-mirror dm-bbr"
 MODULES_MDRAID="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
 
diff --git a/xenU/modules_load b/xenU/modules_load
index 85dfa5f..8b7f360 100644
--- a/xenU/modules_load
+++ b/xenU/modules_load
@@ -3,9 +3,9 @@
 # RAID
 MODULES_ATARAID="ataraid pdcraid hptraid"
 MODULES_DMRAID="dm-mod dm-mirror"
-MODULES_EVMS2="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
+MODULES_EVMS="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
-MODULES_LVM2="dm-mod dm-snapshot dm-mirror dm-bbr"
+MODULES_LVM="dm-mod dm-snapshot dm-mirror dm-bbr"
 MODULES_MDRAID="dm-mod dm-snapshot dm-mirror dm-bbr raid0 raid1 raid456 \
 raid5 raid6 raid10"
diff --git a/gen_configkernel.sh b/gen_configkernel.sh
index 334de42..5f9ef2f 100644
--- a/gen_configkernel.sh
+++ b/gen_configkernel.sh
@@ -102,8 +102,8 @@ config_kernel() {
 	    sed -i ${KERNEL_DIR}/.config -e 's/#\? \?CONFIG_EXT2_FS[ =].*/CONFIG_EXT2_FS=y/g'
 	fi
 
-	# Make sure lvm2 modules are on if --lvm2
-	if isTrue ${CMD_LVM2}
+	# Make sure lvm modules are on if --lvm/--lvm
+	if isTrue ${CMD_LVM}
 	then
 		sed -i ${KERNEL_DIR}/.config -e 's/#\? \?CONFIG_BLK_DEV_DM is.*/CONFIG_BLK_DEV_DM=m/g'
 		sed -i ${KERNEL_DIR}/.config -e 's/#\? \?CONFIG_DM_SNAPSHOT is.*/CONFIG_DM_SNAPSHOT=m/g'
diff --git a/gen_initrd.sh b/gen_initrd.sh
index 005f5da..f48856b 100644
--- a/gen_initrd.sh
+++ b/gen_initrd.sh
@@ -119,26 +119,26 @@ create_base_initrd_sys() {
 			gen_die "Could not extract dmraid binary cache!";
 	fi
 
-	# LVM2
-	if [ "${LVM2}" = '1' ]
+	# LVM
+	if [ "${LVM}" = '1' ]
 	then
 		if [ -e '/sbin/lvm' ] && LC_ALL="C" ldd /sbin/lvm|grep -q 'not a dynamic executable';
 		then
-			print_info 1 'LVM2: Adding support (using local static binaries)...'
+			print_info 1 'LVM: Adding support (using local static binaries)...'
 			cp /sbin/lvm "${TEMP}/initrd-temp/bin/lvm" ||
 				gen_die 'Could not copy over lvm!'
 		else
-			print_info 1 'LVM2: Adding support (compiling binaries)...'
-			compile_lvm2
+			print_info 1 'LVM: Adding support (compiling binaries)...'
+			compile_lvm
 
-			/bin/tar -jxpf "${LVM2_BINCACHE}" -C "${TEMP}/initrd-temp" ||
-				gen_die "Could not extract lvm2 binary cache!";
+			/bin/tar -jxpf "${LVM_BINCACHE}" -C "${TEMP}/initrd-temp" ||
+				gen_die "Could not extract lvm binary cache!";
 			mv ${TEMP}/initrd-temp/bin/lvm.static ${TEMP}/initrd-temp/bin/lvm ||
-				gen_die 'LVM2 error: Could not move lvm.static to lvm!'
+				gen_die 'LVM error: Could not move lvm.static to lvm!'
 		fi
 		for i in vgchange vgscan; do
 			ln  ${TEMP}/initrd-temp/bin/lvm ${TEMP}/initrd-temp/bin/$i ||
-				gen_die "LVM2 error: Could not link ${i}!"
+				gen_die "LVM error: Could not link ${i}!"
 		done
 		mkdir -p ${TEMP}/initrd-temp/etc/lvm
 		if [ -x /sbin/lvm ]
@@ -155,42 +155,42 @@ create_base_initrd_sys() {
 		fi
 	fi
 	
-	# EVMS2
-	if [ "${EVMS2}" = '1' ]
+	# EVMS
+	if [ "${EVMS}" = '1' ]
 	then
 		if [ -e '/sbin/evms_activate' ]
 		then
-			print_info 1 'EVMS2: Adding support...'	
+			print_info 1 'EVMS: Adding support...'	
 			mkdir -p ${TEMP}/initrd-temp/lib
 			mkdir -p ${TEMP}/initrd-temp/sbin
 			mkdir -p ${TEMP}/initrd-temp/etc
 			mkdir -p ${TEMP}/initrd-temp/bin
 			cp -a /lib/ld-* "${TEMP}/initrd-temp/lib" \
-				|| gen_die 'Could not copy files for EVMS2!'
+				|| gen_die 'Could not copy files for EVMS!'
 			if [ -n "`ls /lib/libgcc_s*`" ]
 			then
 				cp -a /lib/libgcc_s* "${TEMP}/initrd-temp/lib" \
-					|| gen_die 'Could not copy files for EVMS2!'
+					|| gen_die 'Could not copy files for EVMS!'
 			fi
 			cp -a /lib/libc-* /lib/libc.* "${TEMP}/initrd-temp/lib" \
-				|| gen_die 'Could not copy files for EVMS2!'
+				|| gen_die 'Could not copy files for EVMS!'
 			cp -a /lib/libdl-* /lib/libdl.* "${TEMP}/initrd-temp/lib" \
-				|| gen_die 'Could not copy files for EVMS2!'
+				|| gen_die 'Could not copy files for EVMS!'
 			cp -a /lib/libpthread* "${TEMP}/initrd-temp/lib" \
-				|| gen_die 'Could not copy files for EVMS2!'
+				|| gen_die 'Could not copy files for EVMS!'
 			cp -a /lib/libuuid*so* "${TEMP}/initrd-temp/lib" \
-				|| gen_die 'Could not copy files for EVMS2!'
+				|| gen_die 'Could not copy files for EVMS!'
 			cp -a /lib/libevms*so* "${TEMP}/initrd-temp/lib" \
-				|| gen_die 'Could not copy files for EVMS2!'
+				|| gen_die 'Could not copy files for EVMS!'
 			cp -a /lib/evms "${TEMP}/initrd-temp/lib" \
-				|| gen_die 'Could not copy files for EVMS2!'
+				|| gen_die 'Could not copy files for EVMS!'
 			cp -a /lib/evms/* "${TEMP}/initrd-temp/lib/evms" \
-				|| gen_die 'Could not copy files for EVMS2!'
+				|| gen_die 'Could not copy files for EVMS!'
 			cp -a /etc/evms.conf "${TEMP}/initrd-temp/etc" \
-				|| gen_die 'Could not copy files for EVMS2!'
+				|| gen_die 'Could not copy files for EVMS!'
 			cp /sbin/evms_activate "${TEMP}/initrd-temp/sbin" \
 				|| gen_die 'Could not copy over evms_activate!'
 			# Fix EVMS2 complaining that it cant find the swap utilities.
 			# These are not required in the initrd
 			for swap_libs in "${TEMP}/initrd-temp/lib/evms/*/swap*.so"
 			do
@@ -155,42 +155,42 @@ create_base_initrd_sys() {
 			cp /sbin/evms_activate "${TEMP}/initrd-temp/sbin" \
 				|| gen_die 'Could not copy over evms_activate!'
-			# Fix EVMS2 complaining that it cant find the swap utilities.
+			# Fix EVMS complaining that it cant find the swap utilities.
 			# These are not required in the initrd
 			for swap_libs in "${TEMP}/initrd-temp/lib/evms/*/swap*.so"